#
# spec file for package testdisk
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           testdisk
Version:        7.1
Release:        bp153.1.17
Summary:        Tool to Recover and Fix Partitions
License:        GPL-2.0
Group:          System/Filesystems
Url:            https://www.cgsecurity.org/wiki/TestDisk
Source0:        https://www.cgsecurity.org/%{name}-%{version}.tar.bz2
BuildRequires:  hicolor-icon-theme
BuildRequires:  libewf-devel
BuildRequires:  libext2fs-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libreiserfs-devel
BuildRequires:  libuuid-devel
BuildRequires:  ncurses-devel
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
%if 0%{?suse_version} >= 1210
BuildRequires:  libntfs-3g-devel
%else
BuildRequires:  ntfsprogs-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
TestDisk is a data recovery software primarily designed to help recover lost
partitions and/or make non-booting disks bootable again.

%package -n photorec
Summary:        Tool to Undelete Files
Group:          System/Filesystems

%description -n photorec
PhotoRec is a file data recovery software designed to recover lost files
including video, documents and archives from hard disks and CD Rom and lost
pictures (Photo Recovery) from digital camera memory. PhotoRec ignores the
filesystem and goes after the underlying data, so it works even if your media's
filesystem is severely damaged or reformatted.

%package -n qphotorec
Summary:        Graphical tool to Undelete Files
Group:          System/Filesystems

%description -n qphotorec
QPhotoRec is a Graphical User Interface (Qt based GUI) version of PhotoRec.
More user friendly, it recognizes the same file formats.

%prep
%define TAR_TOP_FOLDER %{name}-%{version}
%setup -q -n %{TAR_TOP_FOLDER}
cp README.md README

%build
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install
# move back the documentation
mv %{buildroot}%{_datadir}/doc/%{name}/* .

%suse_update_desktop_file qphotorec

%files
%defattr(-,root,root,-)
%license COPYING
%doc AUTHORS ChangeLog NEWS README THANKS documentation.html
%{_bindir}/testdisk
%{_mandir}/man8/testdisk.8%{ext_man}
%{_mandir}/zh_CN/man8/testdisk.8%{ext_man}

%files -n photorec
%defattr(-,root,root,-)
%license COPYING
%doc AUTHORS ChangeLog NEWS README THANKS documentation.html
%{_bindir}/fidentify
%{_bindir}/photorec
%{_mandir}/man8/fidentify.8%{ext_man}
%{_mandir}/man8/photorec.8%{ext_man}
%{_mandir}/zh_CN/man8/fidentify.8%{ext_man}
%{_mandir}/zh_CN/man8/photorec.8%{ext_man}

%files -n qphotorec
%defattr(-,root,root,-)
%license COPYING
%doc AUTHORS ChangeLog NEWS README THANKS documentation.html
%{_bindir}/qphotorec
%{_datadir}/applications/qphotorec.desktop
%{_datadir}/icons/hicolor/48x48/apps/qphotorec.png
%{_datadir}/icons/hicolor/scalable/apps/qphotorec.svg
%{_mandir}/man8/qphotorec.8%{ext_man}
%{_mandir}/zh_CN/man8/qphotorec.8%{ext_man}

%changelog
* Sat Jul 27 2019 opensuse.lietuviu.kalba@gmail.com
- remove testdisk-file-contains-date-and-time.patch as
  RECORD_COMPILATION_DATE is undef by default.
- use "%%license COPYING" instead of "%%doc" in RPM spec.
* Wed Jul 17 2019 opensuse.lietuviu.kalba@gmail.com
- update to 7.1 stable version
  * PhotoRec & QPhotoRec improvements
  - Recover more fragmented files.
* Sun Apr 28 2019 opensuse.lietuviu.kalba@gmail.com
- update to version 7.1-beta:
  * TestDisk
    + Ask confirmation when user quits the list of partitions found by TestDisk
    + Various bug fixes for scripted run
  * PhotoRec & QPhotoRec
    + Improvements
  - Log the correct filenames in photorec.log file
  - Reduced false positives for tar
  - Fix recovery of mobius camera videos.
  - Fix recovery of progressive jpeg
  - Extract the filesize from sqlite header when available
    + New file formats recovered by PhotoRec:
  - .aes: Synology AES key files
  - .axp: Pinnacle Studio
  - .bdm: AVHCD index
  - .cpi: AVCHD Clip Information
  - .DS_Store: Apple Desktop Services Store
  - .dvr: RT60
  - .gi: Roxio Creator
  - .gpx: Guitar Pro 6
  - .gp4: Guitar Pro 4
  - .iam/.ipt Autodesk Inventor part
  - .icns: Apple Icon Image
  - .jsonlz4: Mozilla bookmarks
  - .lyx LyX 2.X
  - .mpl: AVHCD playlist
  - .tg Tux Guitar 1.2
  - .vdj: VirtualDJ
  - .wee: weecast
  - .xar: XAR Archive
- switch from Qt4 to Qt5 for QPhotoRec.
* Sat May  2 2015 benoit.monin@gmx.fr
- update to version 7.0:
  * General Improvements:
    Various fix including security fix, thanks to
    + Coverity scan (Static Analysis of source code)
    + afl-fuzz (security-oriented fuzzer)
    + Denis Andzakovic from Security Assessment for reporting an
    exploitable Stack Buffer Overflow
  * TestDisk
    + Improvements:
  - exFAT: better support
  - ext4: handle 64 bit blocks or 64 KiB blocksize
    Fix detection and file listing
    + Bug fixes:
  - Avoid erroneous error when writing 512 bytes on hard disk
    using 4k sector
  - FAT, NTFS: avoid NULL pointer dereference if localtime()
    returns NULL
  * PhotoRec & QPhotoRec
    QPhotoRec is a Graphical User Interface (Qt based GUI) version
    of PhotoRec. More user friendly, it recognizes the same file
    formats.
    + Improvements:
  - Reduced false positives for more than 80 file formats.
  - .gif: fix filesize detection
  - .flv: add Flash filesize detection
  - .mpg: detect filesize for MPEG
  - .ra: detect filesize for RealAudio3
  - Improved algorithm to deal with data fragmentation
    resulting in a general speed increased
  - Speedup brute-force mode. Brute-force mode can recover more
    fragmented files, but it's still slow and not 100%% reliable
  + New file formats recovered by PhotoRec:
  - .3dm: Rhino / openNURBS
  - .ari: ARRI Raw Video
  - .camrec: Camtasia Studio
  - .dad: Micae DVR
  - .dcm: Digital Imaging and Communications in Medicine (DICOM)
  - .fp12: File Maker Pro 12
  - .kra: Krita
  - .mlv: Magic Lantern Video
  - .notebook: SMART notebook
  - .ora: Mypaint
  - .red: RED2 video format
  - .rlv: Revelation password
  - .vbm: Veeam Backup Metadata
  - .woff: Web Open Font Format
- drop testdisk_614_fix_ext2_check.patch: fixed upstream
- fix documentation path in %%install
- add new subpackage for qphotorec:
  * add build dependencies hicolor-icon-theme, libqt4-devel
    and update-desktop-files
  * run suse_update_desktop_file on qphotorec
- add translated (zh_CN) manpages to each package
* Tue May 27 2014 asterios.dramis@gmail.com
- Update to version 6.14:
  General Improvements
  * The log file generated by the Windows version (cygwin) reports bad sectors
    in a more readable fashion, example <code>ReadFile Data error (cyclic
    redundancy check)</code>.
  * As openssl isn't used, don't link with this cryptographic library (Debian
    tries to avoid mixing GPL code and openssl)
  + TestDisk
  Improvements
  * <code>testdisk /list</code> now displays the disk model, serial number,
    firmware version and hpa or dco presence if detected
  * Recover WBFS (Wii Backup File System) partition
  * Make FAT RebuildBS works when there is a single FAT table
  * Interface: Display the partition table type if autodetected
  * Interface: modified warning about mismatching geometry between FAT or NTFS
    boot sector and HD geometry information
    ([http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=651756 Debian #651756])
  * Interface: Remove "Allow partial last cylinder" option
  Bug fixes
  * Fix crc in EFI backup GPT
  * Rewrote how TestDisk aligns partition on cylinder or 1MB boundary. It
    avoids to create partition entry where the partition ends after the end of
    the disk.
  + PhotoRec
  Improvements
  * Improve Olympus .orf recovery
  * Improve WP Mac/WP5/WP6 Corel Documents .wpd files recovery
  * Fix thumbs.db recovery, avoid some false positive with .doc
  * Interface: if less than 10 file families are enabled, display the results
    even if zero has been found yet
  New file formats:
  * .aep After Effects
  * .axx AxCrypt
  * .dp Designer, a Photobook Designer Software
  * .lzh archive
  * .mmap MindManager
  * .plt Gerber Graphix Advantage
  * .prproj Adobe Premiere project
  * .psb Adobe Photoshop Image
  * .pts PTGui,  panoramic stitching software
  * .qcp The QCP File Format and Media Types for Speech Data (RFC3625)
  * .shn Shorten audio file
  * .snt Windows Sticky Notes
  * .ttd TinyTag Data
  * .wallet Armory bitcoin wallet
  * .wim Windows imaging (WIM) image
  Bug fixes
  * Fix an endless loop during .caf file recovery
  * Fix tiff recovery including some raw file formats, 64-bit version wasn't
    affected
- Renamed the package from photorec to testdisk (as the original package name).
- Added photorec as a subpackage.
- Added a patch (testdisk_614_fix_ext2_check.patch) to fix ext2 check.
- Added libewf-devel as build requirement.
- Removed libopenssl-devel build requirement (not needed anymore).
* Tue May 27 2014 crrodriguez@opensuse.org
- testdisk-file-contains-date-and-time.patch avoid endless
  republish by removing timestamps from the resulting binaries.
* Fri Dec 27 2013 cfarrell@suse.com
- license update: GPL-2.0
  src/ufs.h and src/xfs.h are GPL-2.0 (only) licensed
* Wed Jun 20 2012 meissner@suse.com
- Update to version 6.13:
  General Improvements
  - Fix UAC manifests for Windows, so users don't need to use right-click "Run As Administrator"
  - TestDisk & PhotoRec are now compatible with both libewf and libewf2, the new version of a library to support the Expert Witness Compression Format (EWF).
  TestDisk
  - Fix image creation, image.dd file wasn't created (Regression introduced in 6.12)
  - Detect Vmware VMFS partition
  - Locate lost GFS2 partition but not yet the size
  - Log HDD serial number and firmware revision
  - List NTFS Alternate Data Streams (ADS)
  PhotoRec
  - Session recovery restarts at the previous location
  - Better MPEG recovery, there should be less concatenated videos.
  - Better JPG recovery, there should be less cases where thumbnails were recovered instead of the picture itself.
  - Handle large avi files using "AVIX" or mov files using 64-bit chunk size.
  - Rename recovered pdf using the title (not perfect)
  - Major cleanup of PhotoRec core code
  New file formats:
  - .caf Core Audio Format
  - .dardar3 archive
  - .ddf Didson Data File (v3 and v4)
  - .gcs GCstart (personal collections manager)
  - .gam Games Factory
  - .hdf Hierarchical Data Format 4
  - .hdr ENVI
  - .max 3ds
  - .oci OpenCanvas Image .oci
  - .par2 archive
  - .psmodel Delcam PowerSHAPE
  - .save Assassin's Creed II backup
  - .sh3d Sweet Home 3D
  - .TiVo video record
  - .vmg Nokia Text Message
  - .wpb OpenCanvas files
* Fri Aug 12 2011 aj@suse.de
- Update to version 6.12:
  * Support for exFAT has been enhanced.
  * More than 60 new file formats have been added to PhotoRec.
  * PhotoRec now generates Digital Forensics XML reports.
  * support for ntfs-3g
  * binaries moved to /usr/bin
  More details in http://www.cgsecurity.org/wiki/TestDisk_6.12_Release
* Thu Apr 15 2010 meissner@suse.de
- Updated to version 6.11
  - TestDisk & PhotoRec 6.11 should use less CPU.
  - testdisk: This new TestDisk version can undelete files for NTFS
    filesystem and recover deleted exFAT and ext4.
  - photorec: Performance improvement when scanning for numerous
    file type
  - Fix several bugs including an endless loop, several memory leaks
    and several out-of-bound memory access
  - lots of new file formats are supported
  See also http://www.cgsecurity.org/wiki/TestDisk_6.11_Release
* Fri Feb 29 2008 ro@suse.de
- update to version 6.9:
  TestDisk & PhotoRec 6.9 comes with numerous improvements:
  - They are compatible with ntfsprogs 2.0, the latest library version for
    accessing NTFS partitions, e2fsprogs 1.40.6, the latest library for accessing
    ext2/ext3 partitions.
  - EFI GUID Partition Table is now supported. EFI GPT is mainly used on Itanium,
    MacBook and Mac Pro.
  - Both utilities can use sudo if the user is not root, this functionnality will
    be enabled for at least MacOSX, so users won't have to go into a command line.
  - Improved Windows disk support, most internal USB card reader should now work.
  - Disk model (ie. ATA ST3120026AS, _NEC DVD_RW ND-4550A...) are now reported
    under Linux.
- update to version 6.8:
  Version 6.8 is mainly a bugfix but some small improvements has been made to
  both TestDisk and PhotoRec:
  - Partition type is now autodetected.
  - TestDisk and PhotoRec can now be used under screen, the screen manager with
    VT100/ANSI terminal emulation.
* Fri Aug  3 2007 meissner@suse.de
- New package:
  - testdisk: recovers deleted partitions
  - photorec: recovers lost files (images, videos, etc.)
